@@ -172,6 +172,26 @@ where
     }
 }
 
+#[allow(clippy::cast_possible_truncation)]
+pub fn serialize_duration_as_nanos<S>(t: &Duration, s: S) -> Result<S::Ok, S::Error>
+where
+    S: Serializer,
+{
+    s.serialize_u64(t.as_nanos() as u64)
+}
+
+#[allow(clippy::cast_possible_truncation)]
+pub fn serialize_opt_duration_as_nanos<S>(t: &Option<Duration>, s: S) -> Result<S::Ok, S::Error>
+where
+    S: Serializer,
+{
+    if let Some(ref dur) = t {
+        s.serialize_u64(dur.as_nanos() as u64)
+    } else {
+        s.serialize_none()
+    }
+}
+
 pub fn serialize_opt_duration_as_f64<S>(t: &Option<Duration>, s: S) -> Result<S::Ok, S::Error>
 where
     S: Serializer,
@@ -190,6 +210,13 @@ where
     Ok(Duration::from_micros(u64::deserialize(deserializer)?))
 }
 
+pub fn deserialize_duration_from_nanos<'de, D>(deserializer: D) -> Result<Duration, D::Error>
+where
+    D: Deserializer<'de>,
+{
+    Ok(Duration::from_nanos(u64::deserialize(deserializer)?))
+}
+
 pub fn de_float_as_duration<'de, D>(deserializer: D) -> Result<Duration, D::Error>
 where
     D: Deserializer<'de>,
